@@ -3,7 +3,7 @@
  *
  *  protocol.c is a part of binkd project
  *
- *  Copyright (C) 1996-2003  Dima Maloff, 5047/13 and others
+ *  Copyright (C) 1996-2004  Dima Maloff, 5047/13 and others
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -12,9 +12,37 @@
  */
 
 /*
- * $Id: protocol.c,v 2.67.2.14 2003/09/15 21:28:31 gul Exp $
+ * $Id: protocol.c,v 2.67.2.23 2006/07/24 20:47:47 gul Exp $
  *
  * $Log: protocol.c,v $
+ * Revision 2.67.2.23  2006/07/24 20:47:47  gul
+ * Use MSG_NOSIGNAL flag for send()
+ *
+ * Revision 2.67.2.22  2005/10/03 07:55:16  gul
+ * Fixed memory leak (thanks to Roman Trunov)
+ *
+ * Revision 2.67.2.21  2005/10/02 18:01:28  gul
+ * Verbously report about mail/files for us when receive TRF from remote.
+ *
+ * Revision 2.67.2.20  2005/10/02 15:23:35  gul
+ * Fileboxes was not scanned for unlisted links
+ *
+ * Revision 2.67.2.19  2005/06/06 17:01:02  stream
+ * Fixed broken ND-mode status.
+ *
+ * Revision 2.67.2.18  2004/11/08 12:05:33  gul
+ * 0.9.8 release
+ *
+ * Revision 2.67.2.17  2004/10/21 17:02:03  gul
+ * Rename trunc() -> trunc_file() due to conflicts under OS/2 EMX and SuSE
+ *
+ * Revision 2.67.2.16  2004/10/18 15:18:16  gul
+ * Minor bugfix (patch from Victor Levenets <aq@takas.lt>)
+ *
+ * Revision 2.67.2.15  2004/10/01 10:05:09  gul
+ * Fixed memory leak
+ * (Reported by Victor Levenets <aq@takas.lt>)
+ *
  * Revision 2.67.2.14  2003/09/15 21:28:31  gul
  * Fix remote IP check logic
  *
@@ -569,7 +597,7 @@ static int send_block (STATE *state)
   if (state->optr && state->oleft)
   {
     Log (7, "sending %li byte(s)", (long) (state->oleft));
-    n = send (state->s, state->optr, state->oleft, 0);
+    n = send (state->s, state->optr, state->oleft, MSG_NOSIGNAL);
     save_errno = TCPERRNO;
     save_err = TCPERR ();
     Log (7, "send() done, rc=%i", n);
@@ -723,7 +751,7 @@ static int perform_action (STATE *state, char *path, char action)
   }
   else if (action == 't')
   {
-    trunc (path);
+    trunc_file (path);
   }
   else if (action == 's')
   {
@@ -886,6 +914,17 @@ static int NUL (STATE *state, char *buf, int sz)
     state->minor = atoi (b + 1);
     Log (6, "remote uses " PRTCLNAME " v.%i.%i", state->major, state->minor);
   }
+  else if (!memcmp (s, "TRF ", 4))
+  {
+    char *mail, *files;
+    if ((mail = getwordx (s + 4, 1, 0)) != NULL &&
+        (files = getwordx (s + 4, 2, 0)) != NULL)
+    {
+      Log (2, "Remote has %sb of mail and %sb of files for us", mail, files);
+      free(files);
+    }
+    if (mail) free(mail);
+  }
   else if (!memcmp (s, "OPT ", 4))
   {
     char *w;
@@ -1741,13 +1780,15 @@ static int GOT (STATE *state, char *args, int sz)
   char *argv[3];
   int n, rc=1;
   char *status = NULL;
+  char *saved_args;
 
-  if (state->ND_flag & WE_ND)
-    status = strdup(args);
-  else
-    ND_set_status("", &state->ND_addr, state);
+  saved_args = xstrdup(args);
   if (parse_msg_args (argc, argv, args, "M_GOT", state))
   {
+    if (state->ND_flag & WE_ND)
+      status = saved_args;
+    else
+      ND_set_status("", &state->ND_addr, state);
     if (!tfile_cmp (&state->out, argv[0], atol (argv[1]), atol (argv[2])))
     {
       Log (2, "remote already has %s", state->out.netname);
@@ -1809,10 +1850,12 @@ static int GOT (STATE *state, char *args, int sz)
 	}
       }
     }
-    return rc;
   }
   else
-    return 0;
+    rc = 0;
+  free(saved_args);
+
+  return rc;
 }
 
 static int EOB (STATE *state, char *buf, int sz)
@@ -2044,7 +2087,7 @@ static void banner (STATE *state)
   if ((!no_MD5) && (!state->to) &&
       ((state->MD_challenge=MD_getChallenge(NULL, state))!=NULL))
   {  /* Answering side MUST send CRAM message as a very first M_NUL */
-    char s[MD5_DIGEST_LEN*2+15]; /* max. length of opt string */
+    char s[MD_CHALLENGE_LEN*2+15]; /* max. length of opt string */
     strcpy(s, "OPT ");
     MD_toString(s+4, state->MD_challenge[0], state->MD_challenge+1);
     state->MD_flag=1;
@@ -2374,7 +2417,7 @@ void protocol (SOCKET socket, FTN_NODE *to, char *current_addr)
 	  state.msgs_in_batch = 0;
 	  state.remote_EOB = state.local_EOB = 0;
 	  if (OK_SEND_FILES (&state))
-	    state.q = q_scan_boxes (state.q, state.fa, state.nfa);
+	    state.q = q_scan_boxes (state.q, state.fa, state.nfa, state.to ? 1 : 0);
 	  continue;
 	}
       }
