@@ -12,9 +12,40 @@
  */
 
 /*
- * $Id: readcfg.h,v 2.0 2001/01/10 12:12:39 gul Exp $
+ * $Id: readcfg.h,v 2.9 2003/03/10 10:57:45 gul Exp $
  *
  * $Log: readcfg.h,v $
+ * Revision 2.9  2003/03/10 10:57:45  gul
+ * Extern declarations moved to header files
+ *
+ * Revision 2.8  2003/03/10 10:39:23  gul
+ * New include file common.h
+ *
+ * Revision 2.7  2003/03/01 18:52:49  gul
+ * use time_t for mtime
+ *
+ * Revision 2.6  2003/03/01 15:00:17  gul
+ * Join skipmask and overwrite into common maskchain
+ *
+ * Revision 2.5  2003/02/22 21:32:46  gul
+ * Amiga Style Outbound support
+ *
+ * Revision 2.4  2003/02/22 14:30:18  gul
+ * Make nNod var static
+ *
+ * Revision 2.3  2002/05/11 08:37:32  gul
+ * Added token deletedirs
+ *
+ * Revision 2.2  2002/05/06 19:25:40  gul
+ * new keyword inboundCase in config
+ *
+ * Revision 2.1  2001/08/24 13:23:28  da
+ * binkd/binkd.c
+ * binkd/readcfg.c
+ * binkd/readcfg.h
+ * binkd/server.c
+ * binkd/nt/service.c
+ *
  * Revision 2.0  2001/01/10 12:12:39  gul
  * Binkd is under CVS again
  *
@@ -58,6 +89,7 @@ extern int call_delay;
 extern int max_servers;
 extern int max_clients;
 extern char sysname[MAXSYSTEMNAME + 1];
+extern char bindaddr[16];
 extern char sysop[MAXSYSOPNAME + 1];
 extern char location[MAXLOCATIONNAME + 1];
 extern char nodeinfo[MAXNODEINFO + 1];
@@ -87,6 +119,11 @@ extern int percents;
 extern int tzoff;
 extern char root_domain[MAXHOSTNAMELEN + 1];
 extern int prescan;
+extern enum inbcasetype { INB_SAVE,INB_UPPER,INB_LOWER,INB_MIXED } inboundcase;
+extern int deletedirs;
+extern int havedefnode;
+extern int connect_timeout;
+extern int syslog_facility;
 #ifdef MAILBOX
 /* FileBoxes dir */
 extern char tfilebox[MAXPATHLEN + 1];
@@ -98,11 +135,19 @@ extern int deleteablebox;
 extern char proxy[MAXHOSTNAMELEN + 40];
 extern char socks[MAXHOSTNAMELEN + 40];
 #endif
+#ifdef AMIGADOS_4D_OUTBOUND
+extern int aso;
+#endif
 extern struct conflist_type 
   { char *path;
     struct conflist_type *next;
     time_t mtime;
   } *config_list;
+extern struct maskchain
+  {
+    struct maskchain *next;
+    char *mask;
+  } *skipmask, *overwrite;
 
 /*
  * Parses and reads the path as a config
@@ -111,4 +156,6 @@ void readcfg (char *path);
 
 int  get_host_and_port (int n, char *host, unsigned short *port, char *src, FTN_ADDR *fa);
 
+char *mask_test(char *filename, struct maskchain *chain);
+
 #endif
