@@ -4,10 +4,18 @@
  * Edited a bit by Dima Maloff for Binkd/0.9.3
  */
 /*
- * $Id: setpttl.c,v 2.0 2001/01/10 12:12:40 gul Exp $
+ * $Id: setpttl.c,v 2.2 2003/02/28 20:39:09 gul Exp $
  *
  * Revision history:
  * $Log: setpttl.c,v $
+ * Revision 2.2  2003/02/28 20:39:09  gul
+ * Code cleanup:
+ * change "()" to "(void)" in function declarations;
+ * change C++-style comments to C-style
+ *
+ * Revision 2.1  2001/10/27 08:31:30  gul
+ * minor fix
+ *
  * Revision 2.0  2001/01/10 12:12:40  gul
  * Binkd is under CVS again
  *
@@ -29,7 +37,7 @@
 /*
  * (xalloc.c) allocate memory or log error
  */
-extern void *xalloc (unsigned long size);
+extern void *xalloc (size_t size);
 extern void *xstrdup (const char *str);
 
 
@@ -106,7 +114,7 @@ typedef unsigned int	*pt_entry_t;
 # endif
 
 # ifndef SPT_PADCHAR
-//#  define SPT_PADCHAR	' '
+/*#  define SPT_PADCHAR	' ' */
 #  define SPT_PADCHAR	'\0'
 # endif
 
@@ -231,6 +239,9 @@ void setproctitle(const char *fmt, ...)
 		(void) write(kmem, buf, PSARGSZ);
 #  endif
 #  if SPT_TYPE == SPT_REUSEARGV
+	if (LastArgv == NULL)
+		return;
+
 	if (i > LastArgv - Argv[0] - 2)
 	{
 		i = LastArgv - Argv[0] - 2;
